==> assemblyline-4.2.0.117.tar.gz: assemblyline-4.2.0.117/assemblyline/odm/messages/archive_heartbeat.py <==
from assemblyline import odm

MSG_TYPES = {"ArchiveHeartbeat"}
LOADER_CLASS = "assemblyline.odm.messages.archive_heartbeat.ArchiveMessage"


@odm.model(description="Archive Metrics")
class Metrics(odm.Model):
    alert = odm.Integer(description="Number of alerts archived")
    cached_file = odm.Integer(description="Number of cached files archived")
    emptyresult = odm.Integer(description="Number of empty results archived")
    error = odm.Integer(description="Number of errors archived")
    file = odm.Integer(description="Number of files archived")
    filescore = odm.Integer(description="Number of filescores archived")
    result = odm.Integer(description="Number of results archived")
    submission = odm.Integer(description="Number of submissions archived")
    submission_tree = odm.Integer(description="Number of submission trees archived")
    submission_summary = odm.Integer(description="Number of submission summaries archived")


@odm.model(description="Archive Heartbeat Model")
class Heartbeat(odm.Model):
    instances = odm.Integer(description="Number of instances")
    metrics = odm.Compound(Metrics, description="Archive metrics")


@odm.model(description="Model for Archive Heartbeat Messages")
class ArchiveMessage(odm.Model):
    msg = odm.Compound(Heartbeat, description="Heartbeat message")
    msg_loader = odm.Enum(values={LOADER_CLASS}, default=LOADER_CLASS, description="Loader class for message")
    msg_type = odm.Enum(values=MSG_TYPES, default="ArchiveHeartbeat", description="Message type")
    sender = odm.Keyword(description="Sender of message")

==> assemblyline-4.6.1.dev179.tar.gz: assemblyline-4.6.1.dev179/assemblyline/odm/messages/archive_heartbeat.py <==
from assemblyline import odm

MSG_TYPES = {"ArchiveHeartbeat"}
LOADER_CLASS = "assemblyline.odm.messages.archive_heartbeat.ArchiveMessage"


@odm.model(description="Archive Metrics")
class Metrics(odm.Model):
    # Indices metrics
    file = odm.Integer(description="Number of files archived")
    result = odm.Integer(description="Number of results archived")
    submission = odm.Integer(description="Number of submissions archived")
    # Messaging metrics
    received = odm.Integer(description="Number of received archive messages")
    exception = odm.Integer(description="Number of exceptions during archiving")
    invalid = odm.Integer(description="Number of invalid archive type errors during archiving")
    not_found = odm.Integer(description="Number of submission not found failures during archiving")


@odm.model(description="Archive Heartbeat Model")
class Heartbeat(odm.Model):
    instances = odm.Integer(description="Number of instances")
    metrics = odm.Compound(Metrics, description="Archive metrics")
    queued = odm.Integer(description="Number of documents to be archived")


@odm.model(description="Model for Archive Heartbeat Messages")
class ArchiveMessage(odm.Model):
    msg = odm.Compound(Heartbeat, description="Heartbeat message")
    msg_loader = odm.Enum(values={LOADER_CLASS}, default=LOADER_CLASS, description="Loader class for message")
    msg_type = odm.Enum(values=MSG_TYPES, default="ArchiveHeartbeat", description="Message type")
    sender = odm.Keyword(description="Sender of message")
